==> tuia-ecb-center-api-1.1.0.9-mix-20200320.100144-2-sources.jar: cn/com/duiba/tuia/ecb/center/mix/req/MixUserReq.java <==
package cn.com.duiba.tuia.ecb.center.mix.req;

import java.io.Serializable;
import java.util.Map;

/**
 * @Author: xianhongwei
 * @Time: 2020-01-11 11:15
 * @Desc:
 */
public class MixUserReq implements Serializable {
    private static final long serialVersionUID = 8667124815713700801L;

    protected Long baseUserId;

    protected Long activityId;

    protected Long slotId;

    protected String deviceId;

    protected Long appId;

    protected String mediaUserId;

    protected Long consumerId;

    protected String rid;

    protected Map<String, String> extParamMap;

    public Long getBaseUserId() {
        return baseUserId;
    }

    public void setBaseUserId(Long baseUserId) {
        this.baseUserId = baseUserId;
    }

    public Long getActivityId() {
        return activityId;
    }

    public void setActivityId(Long activityId) {
        this.activityId = activityId;
    }

    public Long getSlotId() {
        return slotId;
    }

    public void setSlotId(Long slotId) {
        this.slotId = slotId;
    }

    public String getDeviceId() {
        return deviceId;
    }

    public void setDeviceId(String deviceId) {
        this.deviceId = deviceId;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public String getMediaUserId() {
        return mediaUserId;
    }

    public void setMediaUserId(String mediaUserId) {
        this.mediaUserId = mediaUserId;
    }

    public Long getConsumerId() {
        return consumerId;
    }

    public void setConsumerId(Long consumerId) {
        this.consumerId = consumerId;
    }

    public String getRid() {
        return rid;
    }

    public void setRid(String rid) {
        this.rid = rid;
    }

    public Map<String, String> getExtParamMap() {
        return extParamMap;
    }

    public void setExtParamMap(Map<String, String> extParamMap) {
        this.extParamMap = extParamMap;
    }
}

==> tuia-ecb-center-api-1.1.0.41-mix1.5-20200520.084445-1-sources.jar: cn/com/duiba/tuia/ecb/center/mix/req/MixUserReq.java <==
package cn.com.duiba.tuia.ecb.center.mix.req;

import java.io.Serializable;
import java.util.Map;

/**
 * @Author: xianhongwei
 * @Time: 2020-01-11 11:15
 * @Desc:
 */
public class MixUserReq implements Serializable {
    private static final long serialVersionUID = 8667124815713700801L;

    protected Long baseUserId;

    protected Long activityId;

    protected Long slotId;

    protected String deviceId;

    protected Long appId;

    protected String mediaUserId;

    protected Long consumerId;

    protected String rid;

    protected Map<String, String> extParamMap;

    public Long getBaseUserId() {
        return baseUserId;
    }

    public void setBaseUserId(Long baseUserId) {
        this.baseUserId = baseUserId;
    }

    public Long getActivityId() {
        return activityId;
    }

    public void setActivityId(Long activityId) {
        this.activityId = activityId;
    }

    public Long getSlotId() {
        return slotId;
    }

    public void setSlotId(Long slotId) {
        this.slotId = slotId;
    }

    public String getDeviceId() {
        return deviceId;
    }

    public void setDeviceId(String deviceId) {
        this.deviceId = deviceId;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public String getMediaUserId() {
        return mediaUserId;
    }

    public void setMediaUserId(String mediaUserId) {
        this.mediaUserId = mediaUserId;
    }

    public Long getConsumerId() {
        return consumerId;
    }

    public void setConsumerId(Long consumerId) {
        this.consumerId = consumerId;
    }

    public String getRid() {
        return rid;
    }

    public void setRid(String rid) {
        this.rid = rid;
    }

    public Map<String, String> getExtParamMap() {
        return extParamMap;
    }

    public void setExtParamMap(Map<String, String> extParamMap) {
        this.extParamMap = extParamMap;
    }

    public String getAttribute(String key) {
        if (extParamMap == null) {
            return null;
        }
        return extParamMap.get(key);
    }
}
